%% STrussDrawModel.m
%  Draws the model on a figure
%  This file is part of the STrussMatlab program


%% Generate model figure
figure(1) %Initialize figure 1
clf(1) %Clear figure 1

xmin = min(NodesCoordinates(:,1)); %Minimum x-coordinate
xmax = max(NodesCoordinates(:,1)); %Maximum x-coordinate
ymin = min(NodesCoordinates(:,2)); %Minimum y-coordinate
ymax = max(NodesCoordinates(:,2)); %Maximum y-coordinate
zmin = min(NodesCoordinates(:,3)); %Minimum z-coordinate
zmax = max(NodesCoordinates(:,3)); %Maximum z-coordinate

axis([xmin-1 xmax+1 ymin-1 ymax+1 zmin-1 zmax+1]); %Initialize axes


%% Draw elements and element properties
for n=1:NumElements; %Scan all elements
	STrussAssignElementProperties;  %Get properties for n element
    line([x1 x2],[y1 y2],[z1 z2],'Marker','.','MarkerSize',15,'LineStyle','-','LineWidth',2,'Color',[0 0 0]); %Draw line for n element
    element_id=sprintf('%i',n);
    x_60=(0.6*NodesCoordinates(Node_i,1)+0.4*NodesCoordinates(Node_j,1)); %x-coordinate at 60% of the length of n element
    y_60=(0.6*NodesCoordinates(Node_i,2)+0.4*NodesCoordinates(Node_j,2)); %y-coordinate at 60% of the length of n element
    z_60=(0.6*NodesCoordinates(Node_i,3)+0.4*NodesCoordinates(Node_j,3)); %z-coordinate at 60% of the length of n element
    text(x_60,y_60,z_60,element_id,'FontSize',11,'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','bottom','Color',[1 0 0]);
end


%% Draw node constraints
for n=1:NumNodes; %Scan all nodes
    node_id=sprintf('  %i',n);
    text(NodesCoordinates(n,1),NodesCoordinates(n,2),NodesCoordinates(n,3),node_id,'FontSize',12,'FontWeight','bold','HorizontalAlignment','left','Color',[0 0 1]);
    if BoundaryConditions(n,1)~=0 || BoundaryConditions(n,2)~=0 || BoundaryConditions(n,3)~=0
        for i=1:3
            if BoundaryConditions(n,i)==1
                    constraint=sprintf(' x ');
            else
                    constraint=sprintf(' o ');
            end
            switch i
                case 1
                    text(NodesCoordinates(n,1),NodesCoordinates(n,2),NodesCoordinates(n,3),constraint,'FontSize',12,'FontWeight','bold','HorizontalAlignment','right','VerticalAlignment','top','Color',[0 1 0]);
                case 2
                    text(NodesCoordinates(n,1),NodesCoordinates(n,2),NodesCoordinates(n,3),constraint,'FontSize',12,'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','top','Color',[0 1 0]);
                case 3
                    text(NodesCoordinates(n,1),NodesCoordinates(n,2),NodesCoordinates(n,3),constraint,'FontSize',12,'FontWeight','bold','HorizontalAlignment','left','VerticalAlignment','top','Color',[0 1 0]);
            end
        end
    end
end


%% Draw labels, etc
grid on; %Draw grid
xlabel('x Coordinate','FontSize',12)
ylabel('y Coordinate','FontSize',12)
zlabel('z Coordinate','FontSize',12)

FigureTitle=['STrussMatlab Model Geometry : ' InputFileName];

title(FigureTitle,'FontSize',12)
axis equal

% End of file -------------------------------------------------------------